part of katana_module;

/// Module class for generating Document query.
///
/// It is possible to override [build()] to generate a model.
abstract class DocumentQueryModule extends QueryModule<DynamicDocumentModel> {}

/// Module class for generating Collection query.
///
/// It is possible to override [build()] to generate a model.
abstract class CollectionQueryModule
    extends QueryModule<DynamicCollectionModel> {}

/// Module class for generating Query.
///
/// It is possible to override [build()] to generate a model.
abstract class QueryModule<T extends Model> {
  /// Build the model.
  ///
  /// Please inherit and use it.
  @protected
  T build(BuildContext context);

  /// Create a new model.
  ///
  /// Pass the BuildContext when you create it.
  ///
  /// Also, if you use hooks, please make sure that the hooks are loaded at the right time.
  T createState(BuildContext context) => build(context);
}
